@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from django.conf import settings
 from django.contrib import admin
 
 from extra_settings.forms import SettingForm
@@ -12,11 +13,12 @@ class SettingAdmin(admin.ModelAdmin):
     value_fields_names = (
         'value_bool', 'value_date', 'value_datetime', 'value_decimal', 'value_duration',
         'value_email', 'value_file', 'value_float', 'value_image',
-        'value_int', 'value_string', 'value_text', 'value_time', 'value_url',
+        'value_int', 'value_json', 'value_string', 'value_text', 'value_time', 'value_url',
     )
     search_fields = ('name', )
-    list_display = ('name', 'value_type', ) + value_fields_names
-    list_filter = ('value_type', )
+    list_display = ('name', 'value_type', ) + value_fields_names + ('description', )
+    if settings.EXTRA_SETTINGS_SHOW_TYPE_LIST_FILTER:
+        list_filter = ('value_type', )
     list_editable = value_fields_names
     sortable_by = ('name', )
 
@@ -24,9 +26,10 @@ class SettingAdmin(admin.ModelAdmin):
         return SettingForm
 
     def get_fieldsets(self, request, obj=None):
-        fields = ('name', 'value_type', )
         if obj:
-            fields += (obj.value_field_name, )
+            fields = ('name', 'description', obj.value_field_name, )
+        else:
+            fields = ('value_type', 'name', 'description', )
         return (
             (None, {
                 'classes': ('wide', ),
